@@ -2,7 +2,7 @@
 #
 # The MIT License (MIT)
 #
-# Copyright (c) Crossbar.io Technologies GmbH
+# Copyright (c) typedef int GmbH
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -27,3 +27,19 @@
 from autobahn._version import __version__
 
 version = __version__
+
+import os
+import txaio
+
+# this is used in the unit tests (trial/pytest), and when already done here, there
+# is no risk and headaches with finding out if/where an import implies a framework
+if os.environ.get('USE_TWISTED', False) and os.environ.get('USE_ASYNCIO', False):
+    raise RuntimeError('fatal: _both_ USE_TWISTED and USE_ASYNCIO are set!')
+
+if os.environ.get('USE_TWISTED', False):
+    txaio.use_twisted()
+elif os.environ.get('USE_ASYNCIO', False):
+    txaio.use_asyncio()
+else:
+    # neither USE_TWISTED nor USE_ASYNCIO selected from env var
+    pass
